﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.IO;
using System.Data;
using System.Reflection;
using DataAccess;
using DistanceLineStyle;

public partial class Vehicle_Map : System.Web.UI.UserControl
{
    #region Private Variables
    private LayerOverlay dynamicOverlay;
    private LayerOverlay staticOverlay;
    private Dictionary<String, String> layersList = new Dictionary<String, String>();
   #endregion

    #region Properties
    /// <summary>
    /// Is point in Edit or Add mode
    /// </summary>
    public bool IsPoint
    {
        get { return ((this.ViewState["isPoint"] != null) ? Convert.ToBoolean(ViewState["isPoint"]) : false); }
        set { this.ViewState["isPoint"] = value; }
    }
    /// <summary>
    /// IsArea in Edit or Add mode
    /// </summary>
    public bool IsArea
    {
        get { return ((this.ViewState["isArea"] != null) ? Convert.ToBoolean(ViewState["isArea"]) : false); }
        set { this.ViewState["isArea"] = value; }
    }
    /// <summary>
    /// Map Property
    /// </summary>
    public Map Map
    {
        get { return this.mainMap; }
    }
    /// <summary>
    /// Dynamic Overlay
    /// </summary>
    public LayerOverlay DynamicOverlay
    {
        get
        {
            if (this.dynamicOverlay == null)
                this.dynamicOverlay = mainMap.CustomOverlays.Where(l => l.Name == "DynamicOverlay").FirstOrDefault() as LayerOverlay;
            return this.dynamicOverlay;
        }
    }
    /// <summary>
    /// Static Overlay
    /// </summary>
    public LayerOverlay StaticOverlay
    {
        get
        {
            if (this.staticOverlay == null)
                this.staticOverlay = mainMap.CustomOverlays.Where(l => l.Name == "StaticOverlay").FirstOrDefault() as LayerOverlay;
            return this.staticOverlay;
        }
    }
    /// <summary>
    /// Show marker 
    /// </summary>
    public SimpleMarkerOverlay MarkerOverlay
    {
        get { return (this.mainMap.CustomOverlays["Vehicle Markers"] as SimpleMarkerOverlay); }
    }
    /// <summary>
    /// Show Lable for markers
    /// </summary>
    public InMemoryFeatureLayer MarkerLabelOverlay
    {
        get { return (this.DynamicOverlay.Layers["Vehicle Marker Labels"] as InMemoryFeatureLayer); }
    }
    /// <summary>
    /// Show point shape on map
    /// </summary>
    public bool ShowPointShape
    {
        set
        {
            tdPointShape.Visible = value;
        }
    }
    /// <summary>
    /// Show area shape on map
    /// </summary>
    public bool ShowAreaShape
    {
        set
        {
            tdAreaShape.Visible = value;
        }
    }
    /// <summary>
    /// Show ZoomInOut shape on map
    /// </summary>
    public bool ShowZoomInOut
    {
        set
        {
            tdZoomInOut.Visible = value;
        }
    }
    /// <summary>
    /// Show ZoomLevels shape on map
    /// </summary>
    public bool ShowZoomLevels
    {
        set
        {
            tdZoomLevel.Visible = value;
        }
    }
    /// <summary>
    /// Show Panmode on map
    /// </summary>
    public bool ShowPanMode
    {
        set
        {
            tdPanMode.Visible = value;
        }
    }
    /// <summary>
    /// Show Panmode on map
    /// </summary>
    public int ZoomLevel
    {
        get
        {
            if (ViewState["ZoomLevel"] == null)
                return 5;
            else
             return   Convert.ToInt32(ViewState["ZoomLevel"]);
        }
        set
        {
            ViewState["ZoomLevel"] = value;
        }
    }
    /// <summary>
    /// Set or Get LineShape
    /// </summary>
    public LineShape newLineShape
    {
        get
        {
            if (Session["lineShape"] == null)
                return null;
            else
                return ((LineShape)(Session["lineShape"]));
        }
        set
        {
            Session["lineShape"] = value;
        }
    }
    /// <summary>
    /// Get or Set the number of Points
    /// </summary>
    public int NumberOfPoitns
    {
        get
        {
            if (ViewState["NumberOfPoitns"] == null)
                return 0;
            else
                return Convert.ToInt32(ViewState["NumberOfPoitns"]);
        }
        set
        {
            ViewState["NumberOfPoitns"] = value;
        }
    }
    /// <summary>
    /// Get or Set the Start Point
    /// </summary>
    public PointShape StartPoint
    {
        get
        {
            if (ViewState["StartPoint"] == null)
                return new PointShape(0,0);
            else
                return ((PointShape)(ViewState["StartPoint"]));
        }
        set
        {
            ViewState["StartPoint"] = value;
        }
    }
    /// <summary>
    /// Get or Set the End Point
    /// </summary>
    public PointShape EndPoint
    {
        get
        {
            if (ViewState["EndPoint"] == null)
                return new PointShape(0, 0);
            else
                return ((PointShape)(ViewState["EndPoint"]));
        }
        set
        {
            ViewState["EndPoint"] = value;
        }
    }
    /// <summary>
    /// Set or Get the total distance for measuring between points
    /// </summary>
    public double TotalDistance
    {
        get
        {
            if (ViewState["TotalDistance"] == null)
                return 0;
            else
                return Convert.ToDouble(ViewState["TotalDistance"]);
        }
        set
        {
            ViewState["TotalDistance"] = value;
        }
    }
    public PointShape CurrentPoint
    {
        get
        {
            if (ViewState["CurrentPoint"] == null)
                return new PointShape(0,0);
            else
                return ((PointShape)(ViewState["CurrentPoint"]));
        }
        set
        {
            ViewState["CurrentPoint"] = value;
        }
    }

    /// <summary>
    /// Is Measure the distance feature is on/off
    /// </summary>
    public bool isMeasure
    {
        get
        {
            if (ViewState["isMeasure"] == null)
                return false;
            else
                return ((bool)(ViewState["isMeasure"]));
        }
        set
        {
            ViewState["isMeasure"] = value;
        }
    }

    /// <summary>
    /// Show Refresh Button on map
    /// </summary>
    public bool ShowRefreshButton
    {
        set
        {
            tdRefresh.Visible = value;
        }
    }
    #endregion

    #region Page Event
    protected override void OnInit(EventArgs e)
    {
        
        if (!IsPostBack)
        {
            //Setting the javascript funtion
            btnZoomIn.Attributes.Add("onclick", "" + mainMap.ClientID + ".ZoomIn();return false;");
            btnZoomOut.Attributes.Add("onclick", "" + mainMap.ClientID + ".ZoomOut();return false;");
            btnPanMode.Attributes.Add("onclick", "" + mainMap.ClientID + ".SetDrawMode('Normal');");

            staticOverlay = new LayerOverlay();
            staticOverlay.TileType = TileType.SingleTile;
            staticOverlay.Name = "StaticOverlay";
            staticOverlay.IsVisibleInOverlaySwitcher = false;
            staticOverlay.IsBaseOverlay = true;
            //if (TrackingConfiguration.Instance.UseCacheforStaticLayers)
            //{
            //    staticOverlay.ClientCache.CacheId = "StaticLayerCache";
            //    staticOverlay.ServerCache.CacheDirectory = MapPath("~/StaticImageCache/" + Request.Path);
            //}
           
            
            dynamicOverlay = new LayerOverlay();
            dynamicOverlay.TileType = TileType.SingleTile;
            dynamicOverlay.Name = "DynamicOverlay";
            dynamicOverlay.IsVisibleInOverlaySwitcher = false;
            dynamicOverlay.IsBaseOverlay = false;
           
            //if (TrackingConfiguration.Instance.UseCacheforDynamicLayers)
            //{
            //    DynamicOverlay.ClientCache.CacheId = "DynamicLayerCache";
            //    DynamicOverlay.ServerCache.CacheDirectory = MapPath("~/DynamicImageCache/" + Request.Path);
            //}
            mainMap.CustomOverlays.Add(dynamicOverlay);
            mainMap.CustomOverlays.Add(staticOverlay);

            //mainMap.BackgroundOverlay = staticOverlay;
            CreateMarkerOverlay();

            mainMap.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            mainMap.CurrentExtent = new RectangleShape(-51, 65, 30, -70);


            mainMap.MapUnit = GeographyUnit.DecimalDegree;
                       //WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
            //mainMap.CustomOverlays.Add(worldMapKitOverlay);
           

            drawCountry();
            drawShape();
            CreateAreasOverlay();
            CreatePointsOverlay();
            CreatePointsDistance();
            CreateMarkerLabelOverlay();
            mainMap.MapUnit = GeographyUnit.DecimalDegree;
            mainMap.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            mainMap.MapTools.OverlaySwitcher.Enabled = false;
            mainMap.MapTools.MouseMapTool.IsMouseWheelDisabled = false;
            mainMap.MapTools.ScaleLine.Enabled = true;
            mainMap.MapTools.MouseCoordinate.Enabled = true;
            mainMap.MapTools.MiniMap.Enabled = true;
            mainMap.MapTools.LoadingImage.Enabled = false;
            mainMap.MapTools.LoadingImage.Width = 64;
            mainMap.MapTools.LoadingImage.Height = 64;
            mainMap.MapTools.MouseMapTool.IsMouseWheelDisabled = true;
           
            mainMap.MapTools.LoadingImage.ImageUri = new Uri(new Uri(Request.Url.AbsoluteUri), "img/loading.gif");
            mainMap.Click += new EventHandler<MapClickedEventArgs>(mainMap_Click);

            //ContextMenu mapMenu = new ContextMenu();
            //mapMenu.Id = "MapMenu";
            //mapMenu.CssClass = "MapMenu";
            //ContextMenuItem layersMenu = new ContextMenuItem("<a onclick='ShowLayerMenu()' class='popupfield' style='Cursor:hand'>Show/Hide Layers<a>");
            //ContextMenuItem delAreaMenu = new ContextMenuItem("<a onclick='ShowDeleteAreaMenu()' class='popupfield' style='Cursor:hand'>Delete Areas<a>");
            //ContextMenuItem delPointMenu = new ContextMenuItem("<a onclick='ShowDeletePointMenu()' class='popupfield' style='Cursor:hand'>Delete Points<a>");

            //mapMenu.MenuItems.Add(layersMenu);
            //mapMenu.MenuItems.Add(delAreaMenu);
            //mapMenu.MenuItems.Add(delPointMenu);
            //mainMap.ContextMenu = mapMenu;
           

     
            
            

            InMemoryFeatureLayer shapeLayer = new InMemoryFeatureLayer();
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(180, 102, 255, 102), 10, GeoColor.StandardColors.DarkGreen, 1);
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Green, 4, true);
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(180, 102, 255, 102), GeoColor.StandardColors.DarkGreen, 1);
            shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            shapeLayer.DrawingQuality = DrawingQuality.HighQuality;
           
            DynamicOverlay.Layers.Add("shapeLayer", shapeLayer);
            if (!(Page.AppRelativeVirtualPath.ToString().ToLower().IndexOf("pointlist.aspx") >= 0 || Page.AppRelativeVirtualPath.ToString().ToLower().IndexOf("arealist.aspx") >= 0))
                setTimer();
            //LoadAreas();
         }
        else
        {
            if (mainMap.CustomOverlays.Count != 0)
            {
                if (mainMap.CustomOverlays.Contains("StaticOverlay"))
                    staticOverlay = mainMap.CustomOverlays["StaticOverlay"] as LayerOverlay;
                if (mainMap.CustomOverlays.Contains("DynamicOverlay"))
                    dynamicOverlay = mainMap.CustomOverlays["DynamicOverlay"] as LayerOverlay;
            }
        }
        base.OnInit(e);
    }

    /*protected void Page_Load(object sender, EventArgs e)
     {
         if (!IsPostBack)
         {
             //mainMap.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
             //mainMap.CurrentExtent = new RectangleShape(-51, 65, 30, -70);
             //mainMap.MapUnit = GeographyUnit.DecimalDegree;

             //WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
             //mainMap.CustomOverlays.Add(worldMapKitOverlay);
             //mainMap.MapUnit = GeographyUnit.DecimalDegree;
             //mainMap.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
             //mainMap.MapTools.OverlaySwitcher.Enabled = false;
             //mainMap.MapTools.MouseMapTool.IsMouseWheelDisabled = false;
             //mainMap.MapTools.ScaleLine.Enabled = true;
             //mainMap.MapTools.MouseCoordinate.Enabled = true;
             //mainMap.MapTools.MiniMap.Enabled = true;
             //mainMap.MapTools.LoadingImage.Enabled = false;
             //mainMap.MapTools.LoadingImage.Width = 64;
             //mainMap.MapTools.LoadingImage.Height = 64;
             //mainMap.MapTools.LoadingImage.ImageUri = new Uri(new Uri(Request.Url.AbsoluteUri), "img/loading.gif");
             //mainMap.Click += new EventHandler<MapClickedEventArgs>(mainMap_Click);

             //ContextMenu mapMenu = new ContextMenu();
             //mapMenu.Id = "MapMenu";
             //mapMenu.CssClass = "MapMenu";
             //ContextMenuItem layersMenu = new ContextMenuItem("<a onclick='ShowLayerMenu()' class='popupfield' style='Cursor:hand'>Show/Hide Layers<a>");
             //ContextMenuItem delAreaMenu = new ContextMenuItem("<a onclick='ShowDeleteAreaMenu()' class='popupfield' style='Cursor:hand'>Delete Areas<a>");
             //ContextMenuItem delPointMenu = new ContextMenuItem("<a onclick='ShowDeletePointMenu()' class='popupfield' style='Cursor:hand'>Delete Points<a>");

             //mapMenu.MenuItems.Add(layersMenu);
             //mapMenu.MenuItems.Add(delAreaMenu);
             //mapMenu.MenuItems.Add(delPointMenu);
             //mainMap.ContextMenu = mapMenu;



             //CreateAreasOverlay();
             //CreatePointsOverlay();
             //CreateMarkerLabelOverlay();

            
             //InMemoryFeatureLayer shapeLayer = new InMemoryFeatureLayer();
             //shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(180, 102, 255, 102), 10, GeoColor.StandardColors.DarkGreen, 1);
             //shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Green, 4, true);
             //shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(180, 102, 255, 102), GeoColor.StandardColors.DarkGreen, 1);
             //shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
             //shapeLayer.DrawingQuality = DrawingQuality.HighQuality;

            

            
             ////LoadPoints();
             ////LoadAreas();

             //DynamicOverlay.Layers.Add("shapeLayer", shapeLayer);
             //mainMap.ZoomTo(new PointShape(28.0007066666667, -26.0225783333333), mainMap.ClientZoomLevelScales[17]);
         }
        
     }*/

    #endregion

    #region Control Events
    protected void mainMap_Click(object sender, MapClickedEventArgs e)
    {
        if (isMeasure)
        {
            InMemoryFeatureLayer pointShapeLayer = (InMemoryFeatureLayer)DynamicOverlay.Layers["pointShapeLayer"];
            Feature newPoint = new Feature(e.Position);
            InMemoryFeatureLayer lineShapeLayer = (InMemoryFeatureLayer)dynamicOverlay.Layers["lineShapeLayer"];

            LineShape lineShape1 = newLineShape;       
            CurrentPoint = e.Position;
            if (NumberOfPoitns == 0)
            {
                StartPoint = CurrentPoint;
                NumberOfPoitns++;
                newPoint.ColumnValues.Add("Name", "");
                pointShapeLayer.InternalFeatures.Add(newPoint.Id, newPoint);
                lineShape1.Vertices.Add(new Vertex(StartPoint.X, StartPoint.Y));
            }
            else
            {
                
                EndPoint = CurrentPoint;
                lineShape1.Vertices.Add(new Vertex(EndPoint.X, EndPoint.Y));
                lineShapeLayer.InternalFeatures.Add(new Feature(lineShape1));
                //MultilineShape line = StartPoint.GetShortestLineTo(EndPoint, GeographyUnit.DecimalDegree);
                double distance = StartPoint.GetDistanceTo(EndPoint, GeographyUnit.DecimalDegree, DistanceUnit.Kilometer);
                TotalDistance += distance;

                newPoint.ColumnValues.Add("Name", TotalDistance.ToString("f2")+ "km");
                pointShapeLayer.InternalFeatures.Add(newPoint.Id, newPoint);
                dynamicOverlay.Redraw();
                //if (line != null)
                //{
                //    Feature lineFeature = new Feature(line);
                //    //string distanceValue = String.Format("<SPAN>{0} km</SPAN>", TotalDistance.ToString("f2"));
                //    lineShapeLayer.InternalFeatures.Add(lineFeature.Id, lineFeature);
                //}
                //CloudPopup popup;
                //popup = new CloudPopup(NumberOfPoitns.ToString(), EndPoint, distanceValue);
                //mainMap.Popups.Add(popup);
                //popup.AutoSize = true;
                
                StartPoint = EndPoint;
                NumberOfPoitns++;
            }

            dynamicOverlay.Redraw();
        }
    }

    protected void Map1_TrackShapeFinished(object sender, EventArgs e)
    {
        //this event all after points, areas and shapes display on the map
        //InMemoryFeatureLayer shapeLayer = (InMemoryFeatureLayer)DynamicOverlay.Layers["Points"];
        double longitude = 0;
        double latitude = 0;
        if (this.IsPoint)
        {
            //save the new creaated point in dynamic overlay
            foreach (Feature feature in mainMap.EditOverlay.Features)
            {
                feature.ColumnValues.Add("Name", "");
                (DynamicOverlay.Layers["Points"] as InMemoryFeatureLayer).InternalFeatures.Add(feature.Id, feature);
                longitude = feature.GetShape().GetCenterPoint().X;
                latitude = feature.GetShape().GetCenterPoint().Y;
                
            }

            //remove point from edit layer
            mainMap.EditOverlay.Features.Clear();
            DynamicOverlay.Redraw();
            mainMap.EditOverlay.TrackMode = TrackMode.None;
            //Call Point page method "assignMethod"
            Page.GetType().InvokeMember("assignMethod", BindingFlags.InvokeMethod, null, this.Page,new object[] {longitude,latitude});
        }
        else if (this.IsArea)
        {
            //save the new creaated area in dynamic overlay
            foreach (Feature feature in mainMap.EditOverlay.Features)
            {
                feature.ColumnValues.Add("Name", "");
                feature.ColumnValues.Add("AreaType", "TEMP");
                (DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer).InternalFeatures.Add(feature.Id, feature);
            }
            //remove area from edit layer
            mainMap.EditOverlay.Features.Clear();
            DynamicOverlay.Redraw();
            mainMap.EditOverlay.TrackMode = TrackMode.None;
        }
        else if (isMeasure)
        {
            
        }
    }
    protected void btnDrawPoint_Click(object sender, ImageClickEventArgs e)
    {
        //Draw Point on the map

        //disable the measure feature
        isMeasure = false;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
        //Check Point is already available on the map
        InMemoryFeatureLayer pointsOverlay = DynamicOverlay.Layers["Points"] as InMemoryFeatureLayer;
        if (pointsOverlay != null)
        {
            //Check if point is already on the Map or not
            if (pointsOverlay.InternalFeatures.Count > 0) // && intPointID == -1
            {
                ScriptManager.RegisterStartupScript(Page, Page.GetType(), Guid.NewGuid().ToString(), "alert('There is already a Point on the map, you have to either edit it or delete it to create new point.')", true);
            }
            else
            {
                //Set the IsPoint flag and apply the tool
                IsPoint = true;

                Map.EditOverlay.TrackMode = TrackMode.Point;
            }
        }
    }
    protected void btnDraw_Click(object sender, ImageClickEventArgs e)
    {
        //Draw Area Shape on the map

        //Disable the measuring distance feature
        isMeasure = false;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
        //Check if area is already on the map
        InMemoryFeatureLayer shapeLayer = DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer;
        if (shapeLayer != null)
        {
            //Check if shape is already on the Map or not
            if (shapeLayer.InternalFeatures.Count > 0) //&& intAreaID == -1
            {
                ScriptManager.RegisterStartupScript(Page, Page.GetType(), Guid.NewGuid().ToString(), "alert('There is already a Shape on the map, you have to either edit it or delete it to create new shape.')", true);
            }
            else
            {
                //Set the IsArea flag and apply the tool
                IsArea = true;
                switch (((ImageButton)sender).ID)
                {
                    case "btnDrawLine":
                        Map.EditOverlay.TrackMode = TrackMode.Line;
                        break;
                    case "btnDrawRectangle":
                        Map.EditOverlay.TrackMode = TrackMode.Rectangle;
                        break;
                    case "btnDrawSquare":
                        Map.EditOverlay.TrackMode = TrackMode.Square;
                        break;
                    case "btnDrawPolygon":
                        Map.EditOverlay.TrackMode = TrackMode.Polygon;
                        break;
                    case "btnDrawCircle":
                        Map.EditOverlay.TrackMode = TrackMode.Circle;
                        break;
                    case "btnDrawEllipse":
                        Map.EditOverlay.TrackMode = TrackMode.Ellipse;
                        break;
                }
            }
        }
    }
    protected void btnZoomLevel_Click(object sender, ImageClickEventArgs e)
    {
        //set the zoom level 1 - 7
        switch (((ImageButton)sender).ID)
        {
            case "btnZoomLevel1":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[2]);
                ZoomLevel = 2;
                break;
            case "btnZoomLevel2":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[4]);
                ZoomLevel = 4;
                break;
            case "btnZoomLevel3":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[8]);
                ZoomLevel = 8;
                break;
            case "btnZoomLevel4":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[10]);
                ZoomLevel = 10;
                break;
            case "btnZoomLevel5":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[12]);
                ZoomLevel = 12;
                break;
            case "btnZoomLevel6":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[16]);
                ZoomLevel = 16;
                break;
            case "btnZoomLevel7":
                Map.ZoomTo(Map.CurrentExtent.GetCenterPoint(), Map.ClientZoomLevelScales[19]);
                ZoomLevel = 20;
                break;
        }

    }
    protected void btnCancelDraw_Click(object sender, ImageClickEventArgs e)
    {
        //Disable the measure the distance 
        isMeasure = false;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
        //Cleare the Area
        InMemoryFeatureLayer shapeLayer = DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer;
        if (shapeLayer != null)
        {
            //Clear the layer
            shapeLayer.InternalFeatures.Clear();
            DynamicOverlay.Redraw();
        }
    }
    protected void btnEditShape_Click(object sender, ImageClickEventArgs e)
    {
        //Disable the measure distance feature 
        isMeasure = false;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
        //Edit the Area Shape
        InMemoryFeatureLayer shapeLayer = DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer;
        //Make the current layer object editable
        foreach (Feature feature in shapeLayer.InternalFeatures)
        {
            Map.EditOverlay.Features.Add(feature.Id, feature);
        }
        IsArea = true;
        shapeLayer.InternalFeatures.Clear();
        Map.EditOverlay.TrackMode = TrackMode.Edit;
        DynamicOverlay.Redraw();
    }
    protected void btnPointer_Click(object sender, ImageClickEventArgs e)
    {
        //Disable the measure distance feature 
        isMeasure = false;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
        //change the default feature of mouse pointer
        mainMap.Cursor = CursorType.Pointer;
        mainMap.MapTools.MouseMapTool.TrackZoomMaskType = TrackZoomMaskType.None;
    }
    protected void btnPanMode_Click(object sender, ImageClickEventArgs e)
    {
        //Disable the measure distance feature 
        isMeasure = false;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
        //Set the default feature of mouse pointer
        mainMap.Cursor = CursorType.Default;
        mainMap.MapTools.MouseMapTool.TrackZoomMaskType = TrackZoomMaskType.Shift;
    }
    protected void btnPlotPointer_Click(object sender, ImageClickEventArgs e)
    {
        //Set the default feature of mouse pointer
        mainMap.Cursor = CursorType.Default;
        mainMap.MapTools.MouseMapTool.TrackZoomMaskType = TrackZoomMaskType.Shift;
        //Disable the measure distance feature 
        isMeasure = true;
        NumberOfPoitns = 0;
        StartPoint = new PointShape(0, 0);
        EndPoint = new PointShape(0, 0);
        TotalDistance = 0;
        newLineShape = new LineShape();
    }

    protected void mainMap_ExtentChanged(object sender, ExtentChangedEventArgs e)
    {
        ProjectSession.CurrentExtent = e.CurrentExtent;
        ProjectSession.CurrentScale = e.CurrentScale;
    }
    protected void ddlRefresh_SelectedIndexChanged(object sender, EventArgs e)
    {
        //set Page Refresh time interval
        ProjectSession.RefreshTime = ddlRefresh.SelectedValue;
        ddlRefresh.Text = ProjectSession.RefreshTime;
        Page.GetType().InvokeMember("setTimerControl", BindingFlags.InvokeMethod, null, this.Page, new object[] { });
    }
    
    #endregion

    #region Methods
    /// <summary>
    /// Draw country shape on the map
    /// </summary>
    private void drawCountry()
    {
        //Load country shape files
        String fileName = String.Format(@"{0}\{1}", MapPath("~/ShapeFiles"), "cntry02.shp");
        //ScriptManager.RegisterStartupScript(Page, Page.GetType(), Guid.NewGuid().ToString(), "alert('" + MapPath("~/ShapeFiles") + "');alert('" + MapPath("../ShapeFiles/cnt.shp") + "');", true);
        
        ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(fileName);
        worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromHtml("#f5eee6"), GeoColor.FromHtml("#a79e95"));

        //ShapeFileFeatureLayer worldLableLayer = new ShapeFileFeatureLayer(fileName);
        //worldLableLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.Country1("CNTRY_NAME");
        //worldLableLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

        //To display country lables at diffferent zoom levels
        ShapeFileFeatureLayer worldLableLayer = new ShapeFileFeatureLayer(fileName);
        ClassBreakStyle classBreakStyle1 = new ClassBreakStyle("SQKM");
        TextStyle textStyle1 = TextStyles.Country1("CNTRY_NAME");// TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 9, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2, 0, 0);
        textStyle1.FittingPolygon = true;
        TextStyle textStyle2 = TextStyles.Country1("CNTRY_NAME");// TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 12, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 3, 0, 0);
        textStyle2.FittingPolygon = true;
        classBreakStyle1.ClassBreaks.Add(new ClassBreak(243300, textStyle1));
        classBreakStyle1.ClassBreaks.Add(new ClassBreak(3000000, textStyle2));

        ClassBreakStyle classBreakStyle2 = new ClassBreakStyle("SQKM");
        TextStyle textStyle3 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 11, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2, 0, 0);
        TextStyle textStyle4 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 14, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 3, 0, 0);
        classBreakStyle2.ClassBreaks.Add(new ClassBreak(0, textStyle3));
        classBreakStyle2.ClassBreaks.Add(new ClassBreak(3000000, textStyle4));

        ClassBreakStyle classBreakStyle3 = new ClassBreakStyle("SQKM");
        TextStyle textStyle5 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 12, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2, 0, 0);
        TextStyle textStyle6 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 15, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 3, 0, 0);
        classBreakStyle3.ClassBreaks.Add(new ClassBreak(0, textStyle5));
        classBreakStyle3.ClassBreaks.Add(new ClassBreak(3000000, textStyle6));

        ClassBreakStyle classBreakStyle4 = new ClassBreakStyle("SQKM");
        TextStyle textStyle7 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 13, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2, 0, 0);
        TextStyle textStyle8 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 16, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 3, 0, 0);
        classBreakStyle4.ClassBreaks.Add(new ClassBreak(0, textStyle7));
        classBreakStyle4.ClassBreaks.Add(new ClassBreak(3000000, textStyle8));

        ClassBreakStyle classBreakStyle5 = new ClassBreakStyle("SQKM");
        TextStyle textStyle09 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 14, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2, 0, 0);
        TextStyle textStyle10 = TextStyles.Country1("CNTRY_NAME");//TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arial", 18, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 3, 0, 0);
        classBreakStyle5.ClassBreaks.Add(new ClassBreak(0, textStyle09));
        classBreakStyle5.ClassBreaks.Add(new ClassBreak(3000000, textStyle10));

        worldLableLayer.ZoomLevelSet.ZoomLevel03.CustomStyles.Add(classBreakStyle1);
        worldLableLayer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level04;
        worldLableLayer.ZoomLevelSet.ZoomLevel05.CustomStyles.Add(classBreakStyle2);
        worldLableLayer.ZoomLevelSet.ZoomLevel06.CustomStyles.Add(classBreakStyle3);
        worldLableLayer.ZoomLevelSet.ZoomLevel07.CustomStyles.Add(classBreakStyle4);
        worldLableLayer.ZoomLevelSet.ZoomLevel08.CustomStyles.Add(classBreakStyle5);
        worldLableLayer.ZoomLevelSet.ZoomLevel08.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

        
        staticOverlay.Layers.Add(worldLayer);
        staticOverlay.Layers.Add(worldLableLayer);
        //ScriptManager.RegisterStartupScript(Page, Page.GetType(), Guid.NewGuid().ToString(), "alert('" + MapPath("~/ShapeFiles") + "');alert('" + MapPath("../ShapeFiles/cnt.shp") + "');", true);
    }
    /// <summary>
    /// Remove shapes if user has uncheck them and they are still on the map.
    /// </summary>
    private void removeShapes()
    {
        LayerOverlay staticOverlay = this.DynamicOverlay;
        System.Data.DataTable objDt = DataAccess.VtShapeUser.SelectAvailableShapeByUserId(ProjectSession.UserId).Tables[0];
        for (int i = 0; i < objDt.Rows.Count; i++)
        {
            if (staticOverlay.Layers.Contains(Convert.ToString(objDt.Rows[i]["ShapeName"])))
            {
                staticOverlay.Layers.Remove(Convert.ToString(objDt.Rows[i]["ShapeName"]));
                staticOverlay.Redraw();
            }
        }
    }
    /// <summary>
    /// Draw the shapes on the map
    /// </summary>
    public void drawShape()
    {
        
        //remove the shapes on the map
        removeShapes();
        LayerOverlay staticOverlay = this.DynamicOverlay;
        //Get shaps list assign to the user
        System.Data.DataTable dtObj = DataAccess.VtShapeUser.SelectByUserId(ProjectSession.UserId).Tables[0];

        for (int i = 0; i < dtObj.Rows.Count; i++)
        {
            if (!staticOverlay.Layers.Contains(Convert.ToString(dtObj.Rows[i]["ShapeName"])))
            {
                //Assigned user shapes display on the map
                String fileName = String.Format(@"{0}\{1}", MapPath("~/ShapeFiles/"), Convert.ToString(dtObj.Rows[i]["ShapeFile"]));

                ShapeFileFeatureLayer strShapeLayer = new ShapeFileFeatureLayer(fileName);
                if (!File.Exists(Path.ChangeExtension(fileName, ".idx")))
                    ShapeFileFeatureLayer.BuildIndexFile(strShapeLayer.ShapePathFileName);



                //strShapeLayer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                //applyStyle(ref strShapeLayer, Convert.ToString(dtObj.Rows[i]["ShapeFile"]));
                //strShapeLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(getStyle(chkShapes.Items[i].Value));

                //strShapeLayer.ZoomLevelSet.ZoomLevel09.DefaultAreaStyle = AreaStyles;

                //System.Reflection.PropertyInfo zoomLevelProperty=strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel10");
                //ZoomLevel zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                //zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                ZoomLevel zoomLevel = applyZoomSelection(ref strShapeLayer,Convert.ToString(dtObj.Rows[i]["ShapeFile"]));
                strShapeLayer.DrawingMarginPercentage = 100;
                zoomLevel.DefaultTextStyle.FittingLineInScreen = true;
                zoomLevel.DefaultTextStyle.FittingPolygon = true;
                zoomLevel.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
                zoomLevel.DefaultTextStyle.SplineType = SplineType.StandardSplining;
                zoomLevel.DefaultTextStyle.SuppressPartialLabels = true;
                zoomLevel.DefaultTextStyle.GridSize = 10;
                // staticOverlay.IsBaseOverlay = false;
                staticOverlay.Layers.Add(Convert.ToString(dtObj.Rows[i]["ShapeName"]), strShapeLayer);
                staticOverlay.Redraw();

                //mainMap.ZoomTo(new PointShape(28.0007066666667, -26.1925783333333), mainMap.ClientZoomLevelScales[14]);
            }

            else
            {
                if (staticOverlay.Layers.Contains(Convert.ToString(dtObj.Rows[i]["ShapeName"])))
                {
                    //staticOverlay.Layers.Remove(Convert.ToString(dtObj.Rows[i]["ShapeName"]));
                    staticOverlay.Redraw();
                }
            }
        }
    }

    /// <summary>
    /// Applying Zoomlevel selection for various shapes
    /// </summary>
    /// <param name="strShapeLayer"></param>
    /// <param name="Shapetype"></param>
    private ZoomLevel applyZoomSelection(ref ShapeFileFeatureLayer strShapeLayer, string Shapetype)
    {
        //Shapetype = Shapetype.ToLower();
        ZoomLevel zoomLevel;
        GeoColor go;
        System.Reflection.PropertyInfo zoomLevelProperty;
        switch (Shapetype)
        {
            case "BUILT_UP_AREAS.shp":

                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel12");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.MajorRoad1;
                zoomLevel.DefaultPointStyle = PointStyles.City3;
                GeoColor go1 = new GeoColor(75, GeoColor.GeographicColors.Forest);
                zoomLevel.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(go1); //AreaStyles.Forest1;
                zoomLevel.DefaultTextStyle = TextStyles.MajorStreet1("NAME");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "LANDUSE.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel13");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.MajorRoad1;
                zoomLevel.DefaultPointStyle = PointStyles.City4;
                zoomLevel.DefaultAreaStyle = AreaStyles.County1;
                zoomLevel.DefaultTextStyle = TextStyles.County1("TYPE");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "PARKS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel13");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.MajorRoad1;
                zoomLevel.DefaultPointStyle = PointStyles.City4;
                 go = new GeoColor(100, GeoColor.GeographicColors.Grass);
                zoomLevel.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(go); //AreaStyles.Park1;
                zoomLevel.DefaultTextStyle = TextStyles.Park1("NAME");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "POI.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel12");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.MajorRoad1;
                zoomLevel.DefaultPointStyle = PointStyles.City7;
                zoomLevel.DefaultAreaStyle = AreaStyles.County2;
                zoomLevel.DefaultTextStyle = TextStyles.Park1("DESCRIP");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "PRV_STATES.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                zoomLevel.DefaultLineStyle = LineStyles.Utility2;
                zoomLevel.DefaultPointStyle = PointStyles.City6;
                zoomLevel.DefaultAreaStyle = AreaStyles.State2;
                zoomLevel.DefaultTextStyle = TextStyles.State2("PRV_NAME");
                break;
            case "RAILWAYS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel08");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultTextStyle = TextStyles.Railway1("TYPE");
                zoomLevel.DefaultLineStyle = LineStyles.Railway1;
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "RIVERS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel14");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.River1;
                zoomLevel.DefaultTextStyle = TextStyles.River1("NAME");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_MAIN.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel10");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;  //MajorRoad1
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#A9AFB3"), 4);
                zoomLevel.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.StandardColors.Transparent, 0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_MAIN-O.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel10");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;  //MajorRoad2
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //  zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.Red);
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#f20f0f"),4);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#A9AFB3"), 4);
                zoomLevel.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.StandardColors.Transparent, 0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_MAJOR.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel03");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.LightBlue);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#a5d4e3"),4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_OTHER.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;  //LocalRoad1
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.White);#e5e5e5
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#ffffff"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_PRIVATE.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3; //SecondaryRoad1
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.White);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#ffffff"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_RAMP.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3; // MajorRoad4
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.LightBlue);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#a5d4e3"),4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_SEC.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel09");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3; //Interstate3
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.Yellow);#e9e91d
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#e9e91d"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_SUB.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel14");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3; //LocalRoad2
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.White);
               zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#ffffff"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_SUB-O.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel14");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;  //LocalRoad3
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.White);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#ffffff"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_TRACK.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;  //SecondaryRoad2
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.White);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#ffffff"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "ROADS_TRAIL.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.Interstate3;  //LocalRoad1
                zoomLevel.DefaultTextStyle = TextStyles.Interstate3("RD_NAME");
                //zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.StandardColors.White);
                //zoomLevel.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.StandardColors.Gray);
                zoomLevel.DefaultLineStyle.InnerPen = new GeoPen(GeoColor.FromHtml("#ffffff"), 4);
                zoomLevel.DefaultLineStyle.OuterPen= new GeoPen(GeoColor.StandardColors.Transparent,0);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "SUBURBS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel09");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "TOLL_PLAZAS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel10");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.MajorRoad1;
                zoomLevel.DefaultPointStyle = PointStyles.CreateSimpleTriangleStyle(GeoColor.StandardColors.Red, 6); //PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, 6);
                zoomLevel.DefaultTextStyle = TextStyles.Country1("NAME"); //TextStyles.CreateSimpleTextStyle("NAME", "Arial", 12, DrawingFontStyles.Regular, GeoColor.StandardColors.Green, 9, 0);  
                
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "TOWNBOUNDS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel11");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultAreaStyle = AreaStyles.County2;
                zoomLevel.DefaultLineStyle = LineStyles.Utility2;
                zoomLevel.DefaultPointStyle = PointStyles.City4;
                zoomLevel.DefaultTextStyle = TextStyles.City4("TWB_NAME");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "TOWNS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel12");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultLineStyle = LineStyles.MajorRoad1;
                zoomLevel.DefaultPointStyle = PointStyles.City1;
                zoomLevel.DefaultTextStyle = TextStyles.City1("TWN_NAME");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            case "WATER_AREAS.shp":
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel07");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.DefaultAreaStyle = AreaStyles.Water1;
                zoomLevel.DefaultLineStyle = LineStyles.River2;
                zoomLevel.DefaultPointStyle = PointStyles.Capital1;
                zoomLevel.DefaultTextStyle = TextStyles.Water1("NAME");
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
            default:
                zoomLevelProperty = strShapeLayer.ZoomLevelSet.GetType().GetProperty("ZoomLevel10");
                zoomLevel = (ZoomLevel)zoomLevelProperty.GetValue(strShapeLayer.ZoomLevelSet, null);
                zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                break;
        }
        return zoomLevel;
    }
    /// <summary>
    /// Applying styles base on selected shape file and type
    /// </summary>
    /// <param name="strShapeLayer"></param>
    /// <param name="Shapetype"></param>
    private void applyStyle(ref ShapeFileFeatureLayer strShapeLayer, string Shapetype)
    {
        //Shapetype = Shapetype.ToLower();
        switch (Shapetype)
        {
            case "BUILT_UP_AREAS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City3;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.Forest1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.MajorStreet1("NAME");
                break;
            case "LANDUSE.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City4;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.County1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.County1("TYPE");
                break;
            case "PARKS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City4;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.Park1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Park1("NAME");
                break;
            case "POI.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City7;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.County2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Park1("DESCRIP");
                break;
            case "PRV_STATES.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.Utility2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City6;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.State2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.State2("PRV_NAME");
                break;
            case "RAILWAYS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Railway1("TYPE");
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.Railway1;
                break;
            case "RIVERS.shp":
                //strShapeLayer.ZoomLevelSet.ZoomLevel10.CustomStyles.Add(LineStyles.River1);
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.River1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.River1("NAME");
                //strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = LineStyles.River1
                break;
            case "ROADS_MAIN.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.MajorRoad1("RD_NAME");
                break;
            case "ROADS_MAIN-O.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.MajorRoad2("RD_NAME");
                break;
            case "ROADS_MAJOR.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.Interstate1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Interstate1("RD_NAME");
                break;
            case "ROADS_OTHER.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.LocalRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.LocalRoad1("RD_NAME");
                break;
            case "ROADS_PRIVATE.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.SecondaryRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.SecondaryRoad1("RD_NAME");
                break;
            case "ROADS_RAMP.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad4;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.MajorRoad4("RD_NAME");
                break;
            case "ROADS_SEC.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.Highway4;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Highway4("RD_NAME");
                break;
            case "ROADS_SUB.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.LocalRoad2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.LocalRoad2("RD_NAME");
                break;
            case "ROADS_SUB-O.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.LocalRoad3;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.LocalRoad3("RD_NAME");
                break;
            case "ROADS_TRACK.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.SecondaryRoad2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.SecondaryRoad2("RD_NAME");
                break;
            case "ROADS_TRAIL.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.LocalRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.LocalRoad1("RD_NAME");
                break;
            case "SUBURBS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.Urban1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Urban1("SUB_NAME");
                break;
            case "TOLL_PLAZAS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.CreateSimpleTriangleStyle(GeoColor.StandardColors.Red, 6); //PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, 6);
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Country1("NAME"); //TextStyles.CreateSimpleTextStyle("NAME", "Arial", 12, DrawingFontStyles.Regular, GeoColor.StandardColors.Green, 9, 0);  
                break;
            case "TOWNBOUNDS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.County2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.Utility2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City4;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.City4("TWB_NAME");
                break;
            case "TOWNS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.MajorRoad1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.City1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.City1("TWN_NAME");
                break;
            case "WATER_AREAS.shp":
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.Water1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.River2;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.Capital1;
                strShapeLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.Water1("NAME");
                break;

        }

    }

    
    /// <summary>
    /// Zoom the map to particular point at certain level
    /// </summary>
    /// <param name="pnt"></param>
    /// <param name="level"></param>
    public void MapZoom(PointShape pnt, int level)
    {
        mainMap.ZoomTo(pnt, mainMap.ClientZoomLevelScales[level]);
    }
    /// <summary>
    /// Create point overlay with text style, zoom level, point style
    /// </summary>
    protected void CreatePointsOverlay()
    {
        InMemoryFeatureLayer pointsOverlay = new InMemoryFeatureLayer();
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Green, 10);
        pointsOverlay.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = (ApplyUntilZoomLevel)Enum.Parse(typeof(ApplyUntilZoomLevel), String.Format("Level{0}", ProjectConfiguration.PointMaxZoomLevel.PadLeft(2, "0"[0])));  //ApplyUntilZoomLevel.Level17;
        //pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Navy, 5, -5);
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 6, DrawingFontStyles.Regular,
                                                                    GeoColor.StandardColors.Green, 9, 0);
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.FittingLineInScreen = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.FittingPolygon = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.SplineType = SplineType.StandardSplining;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.SuppressPartialLabels = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.BestPlacement = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.GridSize = 10;
        pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.RequiredColumnNames.Add("Name");


        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Green, 4);
        pointsOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = (ApplyUntilZoomLevel)Enum.Parse(typeof(ApplyUntilZoomLevel), String.Format("Level{0}", ProjectConfiguration.PointLabelMaxZoomLevel.PadLeft(2, "0"[0])));  //ApplyUntilZoomLevel.Level16;
        pointsOverlay.FeatureSource.CustomColumnFetch += new EventHandler<CustomColumnFetchEventArgs>(PointColumnFetch);
        pointsOverlay.DrawingQuality = DrawingQuality.HighQuality;
        DynamicOverlay.Layers.Add("Points", pointsOverlay);
    }
    /// <summary>
    /// Create Area Overlay
    /// </summary>
    protected void CreateAreasOverlay()
    {
        InMemoryFeatureLayer AreasOverlay = new InMemoryFeatureLayer();
        AreasOverlay.DrawingQuality = DrawingQuality.HighSpeed;

        TextStyle defaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Navy);
        defaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
        defaultTextStyle.FittingLineInScreen = true;
        defaultTextStyle.FittingPolygon = true;
        defaultTextStyle.SplineType = SplineType.StandardSplining;
        defaultTextStyle.SuppressPartialLabels = true;
        defaultTextStyle.GridSize = 10;
        defaultTextStyle.BestPlacement = true;
        defaultTextStyle.RequiredColumnNames.Add("Name");
        defaultTextStyle.RequiredColumnNames.Add("AreaType");

        AreasOverlay.FeatureSource.CustomColumnFetch += new EventHandler<CustomColumnFetchEventArgs>(AreaColumnFetch);

        //AreaStyle areaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Blue);
        //AreasOverlay.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(areaStyle);
        AreasOverlay.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(defaultTextStyle);
        
        
        ValueStyle valueStyle = new ValueStyle();
        valueStyle.ColumnName = "AreaType";
        valueStyle.ValueItems.Add(new ValueItem("GO", new AreaStyle( new GeoSolidBrush(GeoColor.FromArgb(80, 00, 255, 00)))));
        valueStyle.ValueItems.Add(new ValueItem("NO GO", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(80, 255, 00, 00)))));
        valueStyle.ValueItems.Add(new ValueItem("TEMP", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(80, 00, 00, 255)))));
        valueStyle.ValueItems.Add(new ValueItem("SUB AREA", new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.LightSlateGray))));
        valueStyle.ValueItems.Add(new ValueItem("STAND OFF", new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.LightYellow))));
        AreasOverlay.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(valueStyle);
        AreasOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = (ApplyUntilZoomLevel)Enum.Parse(typeof(ApplyUntilZoomLevel), String.Format("Level{0}", ProjectConfiguration.AreaMaxZoomLevel.PadLeft(2, "0"[0])));  //ApplyUntilZoomLevel.Level16;

        DynamicOverlay.Layers.Add("Areas", AreasOverlay);
        
    }

    ////InMemoryFeatureLayer AreasOverlay = new InMemoryFeatureLayer();
    ////    AreasOverlay.DrawingQuality = DrawingQuality.HighSpeed;

    ////    TextStyle defaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Navy);
    ////    defaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
    ////    defaultTextStyle.FittingLineInScreen = true;
    ////    defaultTextStyle.FittingPolygon = true;
    ////    defaultTextStyle.SplineType = SplineType.StandardSplining;
    ////    defaultTextStyle.SuppressPartialLabels = true;
    ////    defaultTextStyle.GridSize = 10;
    ////    defaultTextStyle.BestPlacement = true;
    ////    defaultTextStyle.RequiredColumnNames.Add("Name");
    ////    defaultTextStyle.RequiredColumnNames.Add("AreaType");

    ////    AreasOverlay.FeatureSource.CustomColumnFetch += new EventHandler<CustomColumnFetchEventArgs>(AreaColumnFetch);

    ////    //AreaStyle areaStyle = AreaStyles.CreateSimpleAreaStyle();
    ////    //AreasOverlay.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(areaStyle);
    ////    AreasOverlay.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(defaultTextStyle);
        
        
    ////    ValueStyle valueStyle = new ValueStyle();
    ////    valueStyle.ColumnName = "AreaType";
    ////    valueStyle.ValueItems.Add(new ValueItem("GO", new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 1), new GeoSolidBrush(GeoColor.FromArgb(30, 00, 255, 00)))));
    ////    valueStyle.ValueItems.Add(new ValueItem("NO GO", new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 1), new GeoSolidBrush(GeoColor.FromArgb(30, 255, 00, 00)))));
    ////    valueStyle.ValueItems.Add(new ValueItem("SUB AREA", new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.LightSlateGray))));
    ////    valueStyle.ValueItems.Add(new ValueItem("STAND OFF", new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.LightYellow))));

    ////    AreasOverlay.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(valueStyle);
    ////    AreasOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = (ApplyUntilZoomLevel)Enum.Parse(typeof(ApplyUntilZoomLevel), String.Format("Level{0}", ProjectConfiguration.AreaMaxZoomLevel.PadLeft(2, "0"[0])));  //ApplyUntilZoomLevel.Level16;

    ////    DynamicOverlay.Layers.Add("Areas", AreasOverlay);
    protected void CreatePointsDistance()
    {
        InMemoryFeatureLayer pointsOverlay = new InMemoryFeatureLayer();
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, 10);
        pointsOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        //pointsOverlay.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Navy, 5, -5);
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 9, DrawingFontStyles.Regular,
                                                                    GeoColor.StandardColors.Green, 9, 0);
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.FittingLineInScreen = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.FittingPolygon = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SplineType = SplineType.StandardSplining;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SuppressPartialLabels = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.BestPlacement = true;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.GridSize = 10;
        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.RequiredColumnNames.Add("Name");
        

        pointsOverlay.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, 6);
        pointsOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        pointsOverlay.FeatureSource.CustomColumnFetch += new EventHandler<CustomColumnFetchEventArgs>(PointDistanceColumnFetch);
        pointsOverlay.DrawingQuality = DrawingQuality.HighQuality;
        DynamicOverlay.Layers.Add("pointShapeLayer", pointsOverlay);

        //InMemoryFeatureLayer pointShapeLayer = new InMemoryFeatureLayer();
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, 6);
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.FittingLineInScreen = true;
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.FittingPolygon = true;
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SplineType = SplineType.StandardSplining;
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SuppressPartialLabels = false;
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 8, DrawingFontStyles.Regular,
        //                                                           GeoColor.StandardColors.Green, 9, 0);
        //pointShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.RequiredColumnNames.Add("Name");
        //pointShapeLayer.FeatureSource.CustomColumnFetch += new EventHandler<CustomColumnFetchEventArgs>(PointDistanceColumnFetch);

        ////InMemoryFeatureLayer lineShapeLayer = new InMemoryFeatureLayer();
        ////lineShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColor.StandardColors.Red, 3));
        ////lineShapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

        //DynamicOverlay.Layers.Add("pointShapeLayer", pointShapeLayer);

        InMemoryFeatureLayer lineShapLayer = new InMemoryFeatureLayer();
        //Adds the CustomDistanceLineStyle for displaying the distance in meter at mid point for each line segment.
        CustomDistanceLineStyle customDistanceLineStyle = new CustomDistanceLineStyle(DistanceUnit.Kilometer, new GeoFont("Arial", 12, DrawingFontStyles.Bold),
            new GeoSolidBrush(GeoColor.StandardColors.Black), new GeoPen(GeoColor.StandardColors.White));
        lineShapLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(customDistanceLineStyle);
        LineShape lineShape = new LineShape();
        newLineShape = null;
        newLineShape = lineShape;
        //Adds a regular LineStyle for displaying in red the LineShape.
        LineStyle lineStyle = new LineStyle(new GeoPen(GeoColor.FromArgb(150, GeoColor.StandardColors.Red), 5));
        lineShapLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(lineStyle);
        lineShapLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        LayerOverlay layerOverlay = new LayerOverlay("LineOverlay", false, TileType.SingleTile);
        layerOverlay.TransitionEffect = TransitionEffect.None;
        layerOverlay.Layers.Add(lineShapLayer);
        DynamicOverlay.Layers.Add("lineShapeLayer", lineShapLayer); 
    }
    /// <summary>
    /// set the point column value select point id
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void PointColumnFetch(object sender, CustomColumnFetchEventArgs e)
    {
        e.ColumnValue = (DynamicOverlay.Layers["Points"] as InMemoryFeatureLayer).InternalFeatures[e.Id].ColumnValues["Name"];
    }
    /// <summary>
    /// set the point distance column value select point id
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void PointDistanceColumnFetch(object sender, CustomColumnFetchEventArgs e)
    {
        e.ColumnValue = (DynamicOverlay.Layers["pointShapeLayer"] as InMemoryFeatureLayer).InternalFeatures[e.Id].ColumnValues["Name"];
    }
    /// <summary>
    /// set the area column value of selected area id
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void AreaColumnFetch(object sender, CustomColumnFetchEventArgs e)
    {
        e.ColumnValue = (DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer).InternalFeatures[e.Id].ColumnValues[e.ColumnName];
    }
    /// <summary>
    /// set marker label column value of selected label id
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void MarkerLabels_CustomColumnFetch(object sender, CustomColumnFetchEventArgs e)
    {
        e.ColumnValue = (DynamicOverlay.Layers["Vehicle Marker Labels"] as InMemoryFeatureLayer).InternalFeatures[e.Id].ColumnValues["Name"];
    }
    /// <summary>
    /// Create Marker overlay 
    /// </summary>
    protected void CreateMarkerOverlay()
    {
        SimpleMarkerOverlay markerOverlay = new SimpleMarkerOverlay("Vehicle Markers");
        mainMap.CustomOverlays.Add(markerOverlay);
    }
    /// <summary>
    /// Create Marker Label overlay with default text style, zoom level 
    /// </summary>
    protected void CreateMarkerLabelOverlay()
    {
        InMemoryFeatureLayer markerLabelsOverlay = new InMemoryFeatureLayer();
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Verdana", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, -58, 15);
        // markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 12, DrawingFontStyles.Bold,
        //            GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 3, -18, 15);
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.FittingLineInScreen = true;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.FittingPolygon = true;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SplineType = SplineType.StandardSplining;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SuppressPartialLabels = true;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.GridSize = 10;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.BestPlacement = true;
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.DrawingLevel = DrawingLevel.LevelOne;
        
        markerLabelsOverlay.FeatureSource.CustomColumnFetch += new EventHandler<CustomColumnFetchEventArgs>(MarkerLabels_CustomColumnFetch);
        markerLabelsOverlay.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.RequiredColumnNames.Add("Name");
        
        this.DynamicOverlay.Layers.Add("Vehicle Marker Labels", markerLabelsOverlay);
    }
    /// <summary>
    /// Load points on the map
    /// </summary>
    public void LoadPoints()
    {
        //clear the point overlay
        InMemoryFeatureLayer pointsOverlay = DynamicOverlay.Layers["Points"] as InMemoryFeatureLayer;
        pointsOverlay.InternalFeatures.Clear();

        //get the list of points of given company id
        DataSet dsPoint = DataAccess.VtPoint.SelectByCompanyId(ProjectSession.CompanyId);

        if (dsPoint != null && dsPoint.Tables["Table"] != null && dsPoint.Tables["Table"].Rows.Count >= 0)
        {
            Double longitude = new Double();
            Double latitude = new Double();
            for (int i = 0; i < dsPoint.Tables["Table"].Rows.Count; i++)
            {
                longitude = Convert.ToString(dsPoint.Tables["Table"].Rows[i]["Longitude"]) != "" ? Convert.ToDouble(dsPoint.Tables["Table"].Rows[i]["Longitude"]) : 0;
                latitude = Convert.ToString(dsPoint.Tables["Table"].Rows[i]["Latitude"]) != "" ? Convert.ToDouble(dsPoint.Tables["Table"].Rows[i]["Latitude"]) : 0;
                if (longitude > 0 || latitude > 0)
                {
                    //create new point at particualr position and assign name to that point
                    Feature newPoint = new Feature(new PointShape(longitude, latitude));
                    newPoint.ColumnValues.Add("Name", Convert.ToString(dsPoint.Tables["Table"].Rows[i]["PointName"]));
                    pointsOverlay.InternalFeatures.Add(newPoint.Id, newPoint);
                }
            }



        }
    }

    /// <summary>
    /// Load points on the map of given data
    /// </summary>
    public void LoadPoints(DataTable dtPoint)
    {
        //clear the point overlay
        InMemoryFeatureLayer pointsOverlay = DynamicOverlay.Layers["Points"] as InMemoryFeatureLayer;
        pointsOverlay.InternalFeatures.Clear();
        dynamicOverlay.Redraw();

        Double longitude = new Double();
        Double latitude = new Double();
        for (int i = 0; i < dtPoint.Rows.Count; i++)
        {
            longitude = Convert.ToString(dtPoint.Rows[i]["Longitude"]) != "" ? Convert.ToDouble(dtPoint.Rows[i]["Longitude"]) : 0;
            latitude = Convert.ToString(dtPoint.Rows[i]["Latitude"]) != "" ? Convert.ToDouble(dtPoint.Rows[i]["Latitude"]) : 0;
            if (longitude > 0 || latitude > 0)
            {
                //create new point at particualr position and assign name to that point
                Feature newPoint = new Feature(new PointShape(longitude, latitude));
                newPoint.ColumnValues.Add("Name", Convert.ToString(dtPoint.Rows[i]["PointName"]));
                pointsOverlay.InternalFeatures.Add(newPoint.Id, newPoint);
            }
        }


    }

    /// <summary>
    /// Load Points selected by the user from tree
    /// </summary>
    /// <param name="areaId"></param>
    /// <summary>
    /// Load point on the map
    /// </summary>
    public void LoadPointsfromTree(string pointId)
    {
        //clear the point overlay
        InMemoryFeatureLayer pointsOverlay = DynamicOverlay.Layers["Points"] as InMemoryFeatureLayer;
        pointsOverlay.InternalFeatures.Clear();
        dynamicOverlay.Redraw();
       
        Double longitude = new Double();
        Double latitude = new Double();
        if (pointId != "")
        {
            //get list of area base on vehicle id
            DataSet dsPoint = DataAccess.VtPointObject.SelectByPointListId(pointId);
            if (dsPoint != null && dsPoint.Tables.Count > 0 && dsPoint.Tables[0].Rows.Count > 0)
            {
                for (int i = 0; i < dsPoint.Tables[0].Rows.Count; i++)
                {
                    longitude = Convert.ToString(dsPoint.Tables[0].Rows[i]["Longitude"]) != "" ? Convert.ToDouble(dsPoint.Tables[0].Rows[i]["Longitude"]) : 0;
                    latitude = Convert.ToString(dsPoint.Tables[0].Rows[i]["Latitude"]) != "" ? Convert.ToDouble(dsPoint.Tables[0].Rows[i]["Latitude"]) : 0;
                    if (longitude > 0 || latitude > 0)
                    {
                        //create new point at particualr position and assign name to that point
                        Feature newPoint = new Feature(new PointShape(longitude, latitude));
                        newPoint.ColumnValues.Add("Name", Convert.ToString(dsPoint.Tables[0].Rows[i]["PointName"]));
                        pointsOverlay.InternalFeatures.Add(newPoint.Id, newPoint);
                    }
                }
            }
        }
    }

    /// <summary>
    /// Load area on the map
    /// </summary>
    public void LoadAreas()
    {
        if (DynamicOverlay.Layers.Count != 0)
        {
            //remove the area on the map
            InMemoryFeatureLayer AreasOverlay = DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer;
            AreasOverlay.InternalFeatures.Clear();
            //get list of area base on vehicle id
            DataSet dsArea = DataAccess.VtAreaObject.SelectByVehicleId(ProjectSession.VehicleId);
            byte[] xyXValues = new byte[8];
            byte[] xyYValues = new byte[8];
            if (dsArea != null && dsArea.Tables.Count > 0 && dsArea.Tables[0].Rows.Count > 0)
            {
                for (int i = 0; i < dsArea.Tables[0].Rows.Count; i++)
                {
                    //get list of verticis of polygon
                    byte[] Vertices = (Byte[])(dsArea.Tables[0].Rows[i]["Vertices"]);
                    int Verts = Convert.ToInt32(dsArea.Tables[0].Rows[i]["Numvert"]);
                    List<Vertex> vertexes = new List<Vertex>();
                    for (int k = 0; k < Verts; k++)
                    {
                        Vertex vertex = new Vertex();
                        for (int j = 0; j < 8; j++)
                            xyXValues[j] = Vertices[(k * 16) + j];
                        vertex.X = System.BitConverter.ToDouble(xyXValues, 0);

                        for (int j = 0; j < 8; j++)
                            xyYValues[j] = Vertices[(k * 16) + j + 8];
                        vertex.Y = System.BitConverter.ToDouble(xyYValues, 0);
                        vertexes.Add(vertex);
                    }
                    //draw the polygon on the map and assigned area name
                    PolygonShape polygonShape = new PolygonShape(new RingShape(vertexes));
                    Feature newPoint = new Feature(polygonShape);
                    newPoint.ColumnValues.Add("Name", Convert.ToString(dsArea.Tables[0].Rows[i]["AreaName"]));
                    newPoint.ColumnValues.Add("AreaType", Convert.ToString(dsArea.Tables[0].Rows[i]["AreaType"]).ToUpper().Trim());
                    AreasOverlay.InternalFeatures.Add(newPoint.Id, newPoint);
                }
            }
        }
    }

    /// <summary>
    /// Load Areas selected by the user from tree
    /// </summary>
    /// <param name="areaId"></param>
    /// <summary>
    /// Load area on the map
    /// </summary>
    public void LoadAreasFromTree(string areaIds)
    {
        if (DynamicOverlay.Layers.Count != 0)
        {
            //remove the area on the map
            InMemoryFeatureLayer AreasOverlay = DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer;
            AreasOverlay.InternalFeatures.Clear();
            dynamicOverlay.Redraw();
            if (areaIds != "")
            {
                //get list of area base on vehicle id
                DataSet dsArea = DataAccess.VtArea.SelectAreaDetailByAreaIdList(areaIds);
                byte[] xyXValues = new byte[8];
                byte[] xyYValues = new byte[8];
                if (dsArea != null && dsArea.Tables.Count > 0 && dsArea.Tables[0].Rows.Count > 0)
                {
                    for (int i = 0; i < dsArea.Tables[0].Rows.Count; i++)
                    {
                        //get list of verticis of polygon
                        byte[] Vertices = (Byte[])(dsArea.Tables[0].Rows[i]["Vertices"]);
                        int Verts = Convert.ToInt32(dsArea.Tables[0].Rows[i]["Numvert"]);
                        List<Vertex> vertexes = new List<Vertex>();
                        for (int k = 0; k < Verts; k++)
                        {
                            Vertex vertex = new Vertex();
                            for (int j = 0; j < 8; j++)
                                xyXValues[j] = Vertices[(k * 16) + j];
                            vertex.X = System.BitConverter.ToDouble(xyXValues, 0);

                            for (int j = 0; j < 8; j++)
                                xyYValues[j] = Vertices[(k * 16) + j + 8];
                            vertex.Y = System.BitConverter.ToDouble(xyYValues, 0);
                            vertexes.Add(vertex);
                        }
                        //draw the polygon on the map and assigned area name
                        PolygonShape polygonShape = new PolygonShape(new RingShape(vertexes));
                        Feature newPoint = new Feature(polygonShape);
                        newPoint.ColumnValues.Add("Name", Convert.ToString(dsArea.Tables[0].Rows[i]["AreaName"]));
                        newPoint.ColumnValues.Add("AreaType", Convert.ToString(dsArea.Tables[0].Rows[i]["AreaType"]).ToUpper().Trim());
                        AreasOverlay.InternalFeatures.Add(newPoint.Id, newPoint);
                    }
                }
            }
        }
    }

    public void LoadArea(int areaId)
    {
        DataTable dtArea = VtArea.Select(areaId).Tables[0];
        if (dtArea != null && dtArea.Rows.Count > 0)
        {
            //remove the area on the map
            InMemoryFeatureLayer AreasOverlay = DynamicOverlay.Layers["Areas"] as InMemoryFeatureLayer;
            AreasOverlay.InternalFeatures.Clear();

            byte[] xyXValues = new byte[8];
            byte[] xyYValues = new byte[8];

            for (int i = 0; i < dtArea.Rows.Count; i++)
            {
                //get list of verticis of polygon
                byte[] Vertices = (Byte[])(dtArea.Rows[i]["Vertices"]);
                int Verts = Convert.ToInt32(dtArea.Rows[i]["Numvert"]);
                List<Vertex> vertexes = new List<Vertex>();
                for (int k = 0; k < Verts; k++)
                {
                    Vertex vertex = new Vertex();
                    for (int j = 0; j < 8; j++)
                        xyXValues[j] = Vertices[(k * 16) + j];
                    vertex.X = System.BitConverter.ToDouble(xyXValues, 0);

                    for (int j = 0; j < 8; j++)
                        xyYValues[j] = Vertices[(k * 16) + j + 8];
                    vertex.Y = System.BitConverter.ToDouble(xyYValues, 0);
                    vertexes.Add(vertex);
                }
                //draw the polygon on the map and assigned area name
                PolygonShape polygonShape = new PolygonShape(new RingShape(vertexes));
                Feature newPoint = new Feature(polygonShape);
                newPoint.ColumnValues.Add("Name", Convert.ToString(dtArea.Rows[i]["AreaName"]));
                newPoint.ColumnValues.Add("AreaType", Convert.ToString(dtArea.Rows[i]["AreaType"]).ToUpper().Trim());
                AreasOverlay.InternalFeatures.Add(newPoint.Id, newPoint);
                if(!Page.IsPostBack)
                    Map.ZoomTo(new PointShape(Convert.ToDouble(dtArea.Rows[i]["MidX"]), Convert.ToDouble(dtArea.Rows[i]["MidY"])), Map.ClientZoomLevelScales[10]);
                else
                    Map.CenterAt(new PointShape(Convert.ToDouble(dtArea.Rows[i]["MidX"]), Convert.ToDouble(dtArea.Rows[i]["MidY"])));
                DynamicOverlay.Redraw();
            }
        }

    }

    /// <summary>
    /// Set the Refresh time of timer
    /// </summary>
    public void setTimer()
    {
        Page.GetType().InvokeMember("setTimerControl", BindingFlags.InvokeMethod, null, this.Page, new object[] { });
        ddlRefresh.Text = ProjectSession.RefreshTime;
    }
    #endregion



   
}
